diff --git a/core/vendor/twig/twig/lib/Twig/Environment.php b/core/vendor/twig/twig/lib/Twig/Environment.php
index 3b25c5e..cc7441f 100644
--- a/core/vendor/twig/twig/lib/Twig/Environment.php
+++ b/core/vendor/twig/twig/lib/Twig/Environment.php
@@ -433,7 +433,7 @@ public function clearCacheFiles()
     /**
      * Gets the Lexer instance.
      *
-     * @return Twig_LexerInterface A Twig_LexerInterface instance
+     * @return Twig_Lexer A Twig_Lexer instance
      */
     public function getLexer()
     {
@@ -447,9 +447,9 @@ public function getLexer()
     /**
      * Sets the Lexer instance.
      *
-     * @param Twig_LexerInterface A Twig_LexerInterface instance
+     * @param Twig_Lexer A Twig_Lexer instance
      */
-    public function setLexer(Twig_LexerInterface $lexer)
+    public function setLexer(Twig_Lexer $lexer)
     {
         $this->lexer = $lexer;
     }
@@ -472,7 +472,7 @@ public function tokenize($source, $name = null)
     /**
      * Gets the Parser instance.
      *
-     * @return Twig_ParserInterface A Twig_ParserInterface instance
+     * @return Twig_Parser A Twig_Parser instance
      */
     public function getParser()
     {
@@ -486,9 +486,9 @@ public function getParser()
     /**
      * Sets the Parser instance.
      *
-     * @param Twig_ParserInterface A Twig_ParserInterface instance
+     * @param Twig_Parser A Twig_Parser instance
      */
-    public function setParser(Twig_ParserInterface $parser)
+    public function setParser(Twig_Parser $parser)
     {
         $this->parser = $parser;
     }
@@ -510,7 +510,7 @@ public function parse(Twig_TokenStream $stream)
     /**
      * Gets the Compiler instance.
      *
-     * @return Twig_CompilerInterface A Twig_CompilerInterface instance
+     * @return Twig_Compiler A Twig_Compiler instance
      */
     public function getCompiler()
     {
@@ -524,9 +524,9 @@ public function getCompiler()
     /**
      * Sets the Compiler instance.
      *
-     * @param Twig_CompilerInterface $compiler A Twig_CompilerInterface instance
+     * @param Twig_Compiler $compiler A Twig_Compiler instance
      */
-    public function setCompiler(Twig_CompilerInterface $compiler)
+    public function setCompiler(Twig_Compiler $compiler)
     {
         $this->compiler = $compiler;
     }
diff --git a/core/vendor/twig/twig/lib/Twig/TokenParserBroker.php b/core/vendor/twig/twig/lib/Twig/TokenParserBroker.php
index ec3fba6..8e617a2 100644
--- a/core/vendor/twig/twig/lib/Twig/TokenParserBroker.php
+++ b/core/vendor/twig/twig/lib/Twig/TokenParserBroker.php
@@ -123,7 +123,7 @@ public function getParser()
         return $this->parser;
     }
 
-    public function setParser(Twig_ParserInterface $parser)
+    public function setParser(Twig_Parser $parser)
     {
         $this->parser = $parser;
         foreach ($this->parsers as $tokenParser) {
diff --git a/core/vendor/twig/twig/lib/Twig/TokenParserBrokerInterface.php b/core/vendor/twig/twig/lib/Twig/TokenParserBrokerInterface.php
index 3f006e3..43f17cb 100644
--- a/core/vendor/twig/twig/lib/Twig/TokenParserBrokerInterface.php
+++ b/core/vendor/twig/twig/lib/Twig/TokenParserBrokerInterface.php
@@ -32,14 +32,14 @@ public function getTokenParser($tag);
     /**
      * Calls Twig_TokenParserInterface::setParser on all parsers the implementation knows of.
      *
-     * @param Twig_ParserInterface $parser A Twig_ParserInterface interface
+     * @param Twig_Parser $parser A Twig_Parser interface
      */
-    public function setParser(Twig_ParserInterface $parser);
+    public function setParser(Twig_Parser $parser);
 
     /**
-     * Gets the Twig_ParserInterface.
+     * Gets the Twig_Parser.
      *
      * @return null|Twig_ParserInterface A Twig_ParserInterface instance or null
      */
     public function getParser();
 }
@@ -32,14 +32,14 @@ public function getTokenParser($tag);
      *
-     * @return null|Twig_ParserInterface A Twig_ParserInterface instance or null
+     * @return null|Twig_Parser A Twig_Parser instance or null
      */
     public function getParser();
